#!/usr/bin/env python3

import larch
from larch.xafs import autobk
import sys
from tkinter import Label, Canvas

sys.path.insert(2, "./GUI/welcome.py")
from welcome import root


class Sum:
    def __init__(self, var_a, var_b, var_ui):
        self.var_a = var_a
        self.var_b = var_b
        self.var_ui = var_ui

    def sum(self, entry):
        self.var_ui = entry

        canvas1 = Canvas(root, width=400, height=300, relief="raised")
        canvas1.pack()

        label3 = Label(
            root, text="The sum is" + self.var_ui + " is:", font=("helvetica", 10)
        )
        canvas1.create_window(200, 210, window=label3)

        label4 = Label(
            root, text=float(self.var_ui) ** 0.5, font=("helvetica", 10, "bold")
        )
        canvas1.create_window(200, 230, window=label4)

        return self.var_a + self.var_b


# ui_sum = Sum(float(input("Variable one")), float(input("Variable two")))
# print("Your sum is:", ui_sum.sum())



from tkinter import Tk, Label, Button, Canvas, Entry
from rootmethod import rootMethod
import sys

sys.path.insert(1, "larch_app")
from larch_app import Sum


# create and edit the app
root = Tk()
root.title("ginRex")
# root.iconbitmap("./Path/file")
root.configure(bg="#E9CCA4")
root.geometry("500x500")

# welcome message
labl = Label(root, text="Welcome to ginRex", bg="#E9CCA4", fg="#000000", pady=10)
labl.pack()

# create root button
rootBtn = Button(root, text="back home", fg="#000000", command=rootMethod)
rootBtn.pack()

# create readData button
readDataBtn = Button(root, text="read Data", fg="#000000")
readDataBtn.pack(pady=5)


# create UI entry box
canvas1 = Canvas(root, width=400, height=300, relief="raised")
canvas1.pack()

entryLabel1 = Label(root, text="Enter variable one:")
entryLabel1.config(font=("helvetica", 10))
canvas1.create_window(200, 100, window=entryLabel1)
entry1 = Entry(root)
test = Sum.Sum(entry1.get())
canvas1.create_window(200, 140, window=entry1)

# canvas2 = Canvas(root, width=400, height=300, relief="raised")
# canvas2.pack()

# entryLabel2 = Label(root, text="Enter variable two:")
# entryLabel2.config(font=("helvetica", 10))
# canvas2.create_window(200, 100, window=entryLabel2)
# entry2 = Entry(root)
# canvas2.create_window(200, 140, window=entry2)

# test Button
testBtn = Button(root, text="foo", command=test)
canvas1.create_window(200, 180, window=testBtn)

root.mainloop()



import sys
import random
from PyQt6.QtWidgets import QWidget, QLabel, QApplication, QPushButton, QVBoxLayout


class MainWindow(QWidget):
    def __init__(self):
        super().__init__()
        self.setupGUI()
        self.button = QPushButton("Click me!")
        self.text = QLabel("Hello World")
        self.layout = QVBoxLayout()
        self.layout.addWidget(self.text)
        self.layout.addWidget(self.button)
        self.setLayout(self.layout)
        self.button.clicked.connect(self.greet)
        self.greet()

    def setupGUI(self):
        self.resize(700, 500)
        self.move(400, 150)
        self.setWindowTitle("ginRex")
        # self.label = QLabel("Welcome to ginRex")
        # self.label.setParent(self)

    def greet(self):
        self.hello = [
            "Hallo Welt",
            "你好，世界",
            "Hei maailma",
            "Hello world",
            "Hola Mundo",
            "Привет мир",
            "Ciao mondo",
        ]
        self.text.setText(random.choice(self.hello))


if __name__ == "__main__":
    app = QApplication(sys.argv)

    form = MainWindow()
    form.show()

    sys.exit(app.exec())



from setuptools import setup, find_packages

VERSION = "0.0.1"
DESCRIPTION = "Python package ginRex"
LONG_DESCRIPTION = "Python package for grazing incidene time-resolved Exafs"


setup(
    name="ginrex",
    version=VERSION,
    author="Sebastian Paripsa",
    author_email="sparipsa@digon.io",
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=["xraylarch",],  # add any additional packages that
    # needs to be installed along with your package.
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Science/Research",
        "Programming Language :: Python :: 3",
        "Operating System :: Microsoft :: Windows",
    ],
)
